### Generate Dotnet Code 
* First of all create xlsx for define table structure
* requirements.txt define python's library
* dependency-injector about IOC pattern build system
* current state .net Code First Class Code Generate
* .net code Webapi code generate